@@ -16,8 +16,7 @@
 # under the License.
 
 from collections import OrderedDict
-import os
-import tempfile
+import os.path
 import yaml
 
 
@@ -59,8 +58,7 @@ class TripleoInventories(object):
 
             # save the plan for this stack in the plans list
             plan = inv['Undercloud']['vars']['plan']
-            if plan is not None:
-                inventory['Undercloud']['vars']['plans'].append(plan)
+            inventory['Undercloud']['vars']['plans'].append(plan)
 
             for key in inv.keys():
                 if key != 'Undercloud':
@@ -88,7 +86,7 @@ class TripleoInventories(object):
                             inventory[new_key] = {
                                 'children': {x: {} for x in roles}
                             }
-                        if 'vars' in inv[key]:
+                        if vars in inv[key]:
                             inventory[new_key]['vars'] = inv[key]['vars']
                         if key == 'allovercloud':
                             # useful to have just stack name refer to children
@@ -107,16 +105,6 @@ class TripleoInventories(object):
         # 'plan' doesn't make sense when using multiple plans
         if len(self.stack_to_inv_obj_map) > 1:
             del inventory['Undercloud']['vars']['plan']
-
-        # Ensure there is an overcloud group for backwards compat
-        # If we don't have an stack named "overcloud" use the first stack
-        if 'overcloud' not in inventory:
-            first_stack = list(self.stack_to_inv_obj_map.keys())[0]
-            if dynamic:
-                inventory['overcloud'] = {'children': [first_stack]}
-            else:
-                inventory['overcloud'] = {'children': {first_stack: {}}}
-
         # sort plans list for consistency
         inventory['Undercloud']['vars']['plans'].sort()
         return inventory
@@ -139,14 +127,8 @@ class TripleoInventories(object):
                 if var in inventory:
                     inventory[var]['vars'].update(value)
 
-        # Atomic update as concurrent tripleoclient commands can call this
-        inventory_file_dir = os.path.dirname(inventory_file_path)
-        with tempfile.NamedTemporaryFile(
-                'w',
-                dir=inventory_file_dir,
-                delete=False) as inventory_file:
+        with open(inventory_file_path, 'w') as inventory_file:
             yaml.dump(inventory, inventory_file, TemplateDumper)
-        os.rename(inventory_file.name, inventory_file_path)
 
     def host(self):
         # Dynamic inventory scripts must return empty json if they don't
