@@ -19,6 +19,7 @@ from collections import OrderedDict
 import logging
 import os.path
 import sys
+import tempfile
 import yaml
 
 from heatclient.exc import HTTPNotFound
@@ -90,9 +91,7 @@ class TripleoInventory(object):
                  host_network=None, ansible_python_interpreter=None,
                  undercloud_connection=UNDERCLOUD_CONNECTION_LOCAL,
                  undercloud_key_file=None, serial=1):
-        self.session = session
         self.hclient = hclient
-        self.hosts_format_dict = False
         self.host_network = host_network or HOST_NETWORK
         self.auth_url = auth_url
         self.cacert = cacert
@@ -141,9 +140,9 @@ class TripleoInventory(object):
         """
         return self.UNDERCLOUD_SERVICES
 
-    def _hosts(self, alist):
+    def _hosts(self, alist, dynamic=True):
         """Static yaml inventories reqire a different hosts format?!"""
-        if self.hosts_format_dict:
+        if not dynamic:
             return {x: {} for x in alist}
         else:
             return alist
@@ -158,10 +157,10 @@ class TripleoInventory(object):
 
         return stack
 
-    def list(self):
+    def list(self, dynamic=True):
         ret = OrderedDict({
             'Undercloud': {
-                'hosts': self._hosts(['undercloud']),
+                'hosts': self._hosts(['undercloud'], dynamic),
                 'vars': {
                     'ansible_host': 'localhost',
                     'ansible_python_interpreter': sys.executable,
@@ -169,9 +168,6 @@ class TripleoInventory(object):
                     # see https://github.com/ansible/ansible/issues/41808
                     'ansible_remote_tmp': '/tmp/ansible-${USER}',
                     'auth_url': self.auth_url,
-                    'cacert': self.cacert,
-                    'os_auth_token':
-                    self.session.get_token() if self.session else None,
                     'plan': self.plan_name,
                     'project_name': self.project_name,
                     'username': self.username,
@@ -179,6 +175,10 @@ class TripleoInventory(object):
             }
         })
 
+        if self.cacert:
+            ret['Undercloud']['vars']['cacert'] = \
+                self.cacert
+
         if self.ansible_python_interpreter:
             ret['Undercloud']['vars']['ansible_python_interpreter'] = \
                 self.ansible_python_interpreter
@@ -190,12 +190,6 @@ class TripleoInventory(object):
                 ret['Undercloud']['vars']['ansible_ssh_private_key_file'] = \
                     self.undercloud_key_file
 
-        swift_url = None
-        if self.session:
-            swift_url = self.session.get_endpoint(service_type='object-store',
-                                                  interface='public')
-        ret['Undercloud']['vars']['undercloud_swift_url'] = swift_url
-
         ret['Undercloud']['vars']['undercloud_service_list'] = \
             self.get_undercloud_service_list()
 
@@ -205,7 +199,7 @@ class TripleoInventory(object):
             ret['Undercloud']['vars']['overcloud_admin_password'] =\
                 admin_password
 
-        if not self.hosts_format_dict:
+        if dynamic:
             # Prevent Ansible from repeatedly calling us to get empty host
             # details
             ret['_meta'] = {'hostvars': self.hostvars}
@@ -263,7 +257,7 @@ class TripleoInventory(object):
 
                 children.append(role)
 
-                if self.hosts_format_dict:
+                if not dynamic:
                     hosts_format = hosts
                 else:
                     hosts_format = [h for h in hosts.keys()]
@@ -304,11 +298,20 @@ class TripleoInventory(object):
                 self.get_overcloud_environment().get(
                     'parameter_defaults', {}).get('ContainerCli')
 
-            ret['overcloud'] = {
-                'children': self._hosts(sorted(children)),
+            ret['allovercloud'] = {
+                'children': self._hosts(sorted(children), dynamic),
                 'vars': overcloud_vars
             }
 
+            ret[self.plan_name] = {
+                'children': self._hosts(['allovercloud'], dynamic)
+            }
+            if self.plan_name != 'overcloud':
+                ret['overcloud'] = {
+                    'children': self._hosts(['allovercloud'], dynamic),
+                    'deprecated': 'Deprecated by allovercloud group in Ussuri'
+                }
+
         # Associate services with roles
         roles_by_service = self.get_roles_by_service(
             self.stack_outputs.get('EnabledServices', {}))
@@ -340,7 +343,7 @@ class TripleoInventory(object):
             if service_children:
                 svc_host = service.lower()
                 ret[svc_host] = {
-                    'children': self._hosts(service_children),
+                    'children': self._hosts(service_children, dynamic),
                     'vars': {
                         'ansible_ssh_user': self.ansible_ssh_user
                     }
@@ -368,8 +371,7 @@ class TripleoInventory(object):
 
         # For some reason the json/yaml format needed for static and
         # dynamic inventories is different for the hosts/children?!
-        self.hosts_format_dict = True
-        inventory = self.list()
+        inventory = self.list(dynamic=False)
 
         if extra_vars:
             for var, value in extra_vars.items():
@@ -378,3 +380,33 @@ class TripleoInventory(object):
 
         with open(inventory_file_path, 'w') as inventory_file:
             yaml.dump(inventory, inventory_file, TemplateDumper)
+
+
+def generate_tripleo_ansible_inventory(heat, auth,
+                                       cacert=None,
+                                       plan='overcloud',
+                                       work_dir=None,
+                                       ansible_python_interpreter=None,
+                                       ansible_ssh_user='tripleo-admin',
+                                       undercloud_key_file=None,
+                                       ssh_network='ctlplane'):
+    if not work_dir:
+        work_dir = tempfile.mkdtemp(prefix='tripleo-ansible')
+
+    inventory_path = os.path.join(
+        work_dir, 'tripleo-ansible-inventory.yaml')
+    inv = TripleoInventory(
+        hclient=heat,
+        auth_url=auth.auth_uri,
+        cacert=cacert,
+        project_name=auth.project_name,
+        username=auth.user_name,
+        ansible_ssh_user=ansible_ssh_user,
+        undercloud_key_file=undercloud_key_file,
+        undercloud_connection=UNDERCLOUD_CONNECTION_SSH,
+        ansible_python_interpreter=ansible_python_interpreter,
+        plan_name=plan,
+        host_network=ssh_network)
+
+    inv.write_static_inventory(inventory_path)
+    return inventory_path
