@@ -13,12 +13,12 @@
 #   under the License.
 #
 
-
-import mock
 import os
 import six
 import sys
 import tempfile
+from unittest import mock
+
 import yaml
 
 from tripleo_common import constants
@@ -119,10 +119,10 @@ class TestKollaImageBuilder(base.TestCase):
             'kolla-build',
             '--config-file',
             'kolla-config.conf',
-            'nova-compute',
-            'nova-libvirt',
-            'heat-docker-agents-centos',
-            'image-with-missing-tag',
+            '^nova-compute$',
+            '^nova-libvirt$',
+            '^heat-docker-agents-centos$',
+            '^image-with-missing-tag$',
         ], env=env, stdout=-1, universal_newlines=True)
 
     @mock.patch('tripleo_common.image.base.open',
@@ -144,10 +144,10 @@ class TestKollaImageBuilder(base.TestCase):
             'kolla-build',
             '--config-file',
             'kolla-config.conf',
-            'nova-compute',
-            'nova-libvirt',
-            'heat-docker-agents-centos',
-            'image-with-missing-tag',
+            '^nova-compute$',
+            '^nova-libvirt$',
+            '^heat-docker-agents-centos$',
+            '^image-with-missing-tag$',
             '--template-only',
             '--work-dir', '/tmp/kolla',
         ], env=env, stdout=-1, universal_newlines=True)
@@ -155,10 +155,10 @@ class TestKollaImageBuilder(base.TestCase):
             'kolla-build',
             '--config-file',
             'kolla-config.conf',
-            'nova-compute',
-            'nova-libvirt',
-            'heat-docker-agents-centos',
-            'image-with-missing-tag',
+            '^nova-compute$',
+            '^nova-libvirt$',
+            '^heat-docker-agents-centos$',
+            '^image-with-missing-tag$',
             '--list-dependencies',
         ], env=env, stdout=-1, stderr=-1, universal_newlines=True)
         calls = [call1, call2]
@@ -200,9 +200,9 @@ class TestKollaImageBuilder(base.TestCase):
             'kolla-build',
             '--config-file',
             'kolla-config.conf',
-            'nova-libvirt',
-            'heat-docker-agents-centos',
-            'image-with-missing-tag',
+            '^nova-libvirt$',
+            '^heat-docker-agents-centos$',
+            '^image-with-missing-tag$',
         ], env=env, stdout=-1, universal_newlines=True)
 
 
