@@ -12,14 +12,15 @@
 
 import datetime
 import fixtures
-import mock
 import os
+from unittest import mock
+from unittest.mock import patch
+from unittest.mock import call
 import uuid
 import warnings
+
 import yaml
 
-from mock import call
-from mock import patch
 
 from tripleo_common import constants
 from tripleo_common.tests import base
@@ -27,6 +28,14 @@ from tripleo_common.tests.fake_config import fakes
 from tripleo_common.utils import config as ooo_config
 from tripleo_common.utils.safe_import import git
 
+RESOURCES_YAML_CONTENTS = """heat_template_version: 2016-04-08
+resources:
+  Controller:
+    type: OS::Heat::ResourceGroup
+  NotRoleContoller:
+    type: OS::Dummy::DummyGroup
+"""
+
 
 class TestConfig(base.TestCase):
 
@@ -147,7 +156,7 @@ class TestConfig(base.TestCase):
                                                'service': 'name=fake '
                                                'state=stopped',
                                                'when': ['nova_api_enabled.rc'
-                                                        ' == 0',
+                                                        ' == 0', False,
                                                         'httpd_enabled.rc'
                                                         ' != 0',
                                                         'step|int == 1']}],
@@ -902,3 +911,126 @@ class TestConfig(base.TestCase):
                          mock_open.call_args_list[0][0][0])
         self.assertEqual('/tmp/tht/Controller/NetworkConfig',
                          mock_open.call_args_list[1][0][0])
+
+
+class OvercloudConfigTest(base.TestCase):
+
+    def setUp(self,):
+        super(OvercloudConfigTest, self).setUp()
+        self.plan = 'overcloud'
+        self.delete_after = 3600
+        self.config_container = 'config-overcloud'
+
+        # setup swift
+        self.template_files = (
+            'some-name.yaml',
+            'some-other-name.yaml',
+            'yet-some-other-name.yaml',
+            'finally-another-name.yaml'
+        )
+        self.swift = mock.MagicMock()
+        self.swift.get_container.return_value = (
+            {'x-container-meta-usage-tripleo': 'plan'}, [
+                {
+                    'name': tf,
+                    'last_modified': '2018-11-05'
+                } for tf in self.template_files
+            ]
+        )
+        self.swift.get_object.return_value = ({}, RESOURCES_YAML_CONTENTS)
+
+    @mock.patch('tripleo_common.utils.swift.delete_container')
+    @mock.patch('tripleo_common.utils.swift.download_container')
+    @mock.patch('tripleo_common.utils.config.Config.download_config')
+    @mock.patch('tripleo_common.utils.tarball.create_tarball')
+    def test_get_overcloud_config(self, mock_create_tarball,
+                                  mock_config,
+                                  mock_swift_download,
+                                  mock_swift_delete):
+        heat = mock.MagicMock()
+        heat.stacks.get.return_value = mock.MagicMock(
+            stack_name='stack', id='stack_id')
+        mock_config.return_value = '/tmp/fake-path'
+
+        ooo_config.get_overcloud_config(
+            self.swift, heat,
+            self.plan,
+            self.config_container,
+            '/tmp/fake-path')
+
+        mock_swift_download.assert_called_once_with(self.swift,
+                                                    self.config_container,
+                                                    '/tmp/fake-path')
+        mock_swift_delete.assert_called_once_with(self.swift,
+                                                  self.config_container)
+        self.assertEqual(2, self.swift.put_object.call_count)
+        self.assertEqual(mock.call(
+            'config-overcloud', 'config-overcloud.tar.gz',
+            self.swift.put_object.call_args_list[1][0][2]),  # closed file call
+            self.swift.put_object.call_args_list[1])
+        mock_create_tarball.assert_called_once()
+        self.assertEqual(dict(excludes=['.tox', '*.pyc', '*.pyo']),
+                         mock_create_tarball.call_args[1])
+
+    @mock.patch('tripleo_common.utils.config.os.unlink')
+    @mock.patch('tripleo_common.utils.config.os.path.exists')
+    @mock.patch('tripleo_common.utils.config.os.symlink')
+    @mock.patch('tripleo_common.utils.swift.download_container')
+    @mock.patch('tempfile.mkdtemp')
+    def test_download_config(self, mock_mkdtemp,
+                             mock_swiftutils,
+                             mock_os_symlink,
+                             mock_os_path_exists,
+                             mock_os_unlink):
+        mock_mkdtemp.return_value = '/tmp/tripleo-foo-config'
+        ooo_config.download_overcloud_config(self.swift,
+                                             self.config_container)
+        mock_swiftutils.assert_called_once_with(self.swift,
+                                                self.config_container,
+                                                '/tmp/tripleo-foo-config')
+
+    @mock.patch('tripleo_common.utils.config.os.path.exists')
+    @mock.patch('tripleo_common.utils.config.os.symlink')
+    @mock.patch('tripleo_common.utils.swift.download_container')
+    @mock.patch('tempfile.mkdtemp')
+    def test_download_create_latest_symlink(
+            self, mock_mkdtemp,
+            mock_swiftutils,
+            mock_os_symlink,
+            mock_os_path_exists):
+        mock_mkdtemp.return_value = '/var/lib/mistral/uuid'
+        mock_os_path_exists.return_value = False
+        ooo_config.download_overcloud_config(self.swift,
+                                             self.config_container)
+        mock_swiftutils.assert_called_once_with(self.swift,
+                                                self.config_container,
+                                                mock_mkdtemp())
+        mock_os_symlink.assert_called_once_with(
+            '/var/lib/mistral/uuid',
+            os.path.join(os.path.dirname('/var/lib/mistral/uuid'),
+                         'config-download-latest'))
+
+    @mock.patch('tripleo_common.utils.config.os.unlink')
+    @mock.patch('tripleo_common.utils.config.os.path.exists')
+    @mock.patch('tripleo_common.utils.config.os.symlink')
+    @mock.patch('tripleo_common.utils.swift.download_container')
+    @mock.patch('tempfile.mkdtemp')
+    def test_download_update_latest_symlink(
+            self, mock_mkdtemp,
+            mock_swiftutils,
+            mock_os_symlink,
+            mock_os_path_exists,
+            mock_os_unlink):
+        mock_mkdtemp.return_value = '/var/lib/mistral/uuid'
+        mock_os_path_exists.return_value = True
+        ooo_config.download_overcloud_config(self.swift,
+                                             self.config_container)
+        mock_swiftutils.assert_called_once_with(self.swift,
+                                                self.config_container,
+                                                mock_mkdtemp())
+        mock_os_symlink.assert_called_once_with(
+            '/var/lib/mistral/uuid',
+            os.path.join(os.path.dirname('/var/lib/mistral/uuid'),
+                         'config-download-latest'))
+        mock_os_unlink.assert_called_once_with(
+            '/var/lib/mistral/config-download-latest')
